@@ -27,5 +27,5 @@ except ImportError:
         if not salt:
             salt = hashlib.sha1(str(random.random()) + str(random.random())).hexdigest()[:5]
             
-        hsh = hashlib.sha1(salt, password)
+        hsh = hashlib.sha1(salt + password)
         return 'sha1$%s$%s' % (salt, hsh)
